==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicLookAndFeel.h <==
// public abstract class javax.swing.plaf.basic.BasicLookAndFeel

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e3f15385cb1dee82 javax_swing_LookAndFeel
// @dep_class 3968edfd325f1d3f javax_swing_plaf_basic_BasicLookAndFeel

// header file dependencies
// @dep_header javax_swing_LookAndFeel

#include "javax/swing/LookAndFeel.h"

#ifndef _JC_javax_swing_plaf_basic_BasicLookAndFeel_H_
#define _JC_javax_swing_plaf_basic_BasicLookAndFeel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_UIDefaults$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_refs	_jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$refs	_jc_javax_swing_plaf_basic_BasicLookAndFeel$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$nonrefs	_jc_javax_swing_plaf_basic_BasicLookAndFeel$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object	_jc_javax_swing_plaf_basic_BasicLookAndFeel$object;

typedef struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$fields_struct	_jc_javax_swing_plaf_basic_BasicLookAndFeel$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$vmethods	_jc_javax_swing_plaf_basic_BasicLookAndFeel$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$vtable	_jc_javax_swing_plaf_basic_BasicLookAndFeel$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$vtype	_jc_javax_swing_plaf_basic_BasicLookAndFeel$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_basic_BasicLookAndFeel$fields_struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicLookAndFeel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *);

// Virtual methods
extern struct _jc_javax_swing_UIDefaults$object *_jc_javax_swing_plaf_basic_BasicLookAndFeel$method$getDefaults$87ffe4e04898b5f1(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *);
extern void _jc_javax_swing_plaf_basic_BasicLookAndFeel$method$initClassDefaults$35477cab17689fae(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *);
extern void _jc_javax_swing_plaf_basic_BasicLookAndFeel$method$initComponentDefaults$b280e29c4e58de45(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *);
extern void _jc_javax_swing_plaf_basic_BasicLookAndFeel$method$initSystemColorDefaults$4d490ebd205ea2d1(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *);
extern void _jc_javax_swing_plaf_basic_BasicLookAndFeel$method$loadResourceBundle$b83922b5072c9519(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *);
extern void _jc_javax_swing_plaf_basic_BasicLookAndFeel$method$loadSystemColors$3d217644e7c3cafd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *, struct _jc_object_array *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicLookAndFeel$method_info$getDefaults$87ffe4e04898b5f1;
extern _jc_method _jc_javax_swing_plaf_basic_BasicLookAndFeel$method_info$initClassDefaults$35477cab17689fae;
extern _jc_method _jc_javax_swing_plaf_basic_BasicLookAndFeel$method_info$initComponentDefaults$b280e29c4e58de45;
extern _jc_method _jc_javax_swing_plaf_basic_BasicLookAndFeel$method_info$initSystemColorDefaults$4d490ebd205ea2d1;
extern _jc_method _jc_javax_swing_plaf_basic_BasicLookAndFeel$method_info$loadResourceBundle$b83922b5072c9519;
extern _jc_method _jc_javax_swing_plaf_basic_BasicLookAndFeel$method_info$loadSystemColors$3d217644e7c3cafd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$vmethods {
	struct _jc_javax_swing_UIDefaults$object	*(*getDefaults$87ffe4e04898b5f1)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *);
	void	(*initClassDefaults$35477cab17689fae)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *);
	void	(*initComponentDefaults$b280e29c4e58de45)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *);
	void	(*initSystemColorDefaults$4d490ebd205ea2d1)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *);
	void	(*loadResourceBundle$b83922b5072c9519)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *);
	void	(*loadSystemColors$3d217644e7c3cafd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *, struct _jc_object_array *, jboolean);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_LookAndFeel$vmethods	javax_swing_LookAndFeel;
	_jc_javax_swing_plaf_basic_BasicLookAndFeel$vmethods	javax_swing_plaf_basic_BasicLookAndFeel;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicLookAndFeel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$refs {
    _jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_refs	javax_swing_plaf_basic_BasicLookAndFeel;
    _jc_javax_swing_LookAndFeel$sub_refs	javax_swing_LookAndFeel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_LookAndFeel$sub_nonrefs	javax_swing_LookAndFeel;
    _jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_nonrefs	javax_swing_plaf_basic_BasicLookAndFeel;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object {
	_jc_javax_swing_plaf_basic_BasicLookAndFeel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicLookAndFeel$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicLookAndFeel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicLookAndFeel$vtype _jc_javax_swing_plaf_basic_BasicLookAndFeel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicLookAndFeel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicLookAndFeel$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicLookAndFeel_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicLookAndFeel.h <==
// public abstract class javax.swing.plaf.basic.BasicLookAndFeel

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e3f15385cb1dee82 javax_swing_LookAndFeel
// @dep_class a2837749b8505c6 javax_swing_plaf_basic_BasicLookAndFeel

// header file dependencies
// @dep_header javax_swing_LookAndFeel

#include "javax/swing/LookAndFeel.h"

#ifndef _JC_javax_swing_plaf_basic_BasicLookAndFeel_H_
#define _JC_javax_swing_plaf_basic_BasicLookAndFeel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_UIDefaults$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_refs	_jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$refs	_jc_javax_swing_plaf_basic_BasicLookAndFeel$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$nonrefs	_jc_javax_swing_plaf_basic_BasicLookAndFeel$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object	_jc_javax_swing_plaf_basic_BasicLookAndFeel$object;

typedef struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$fields_struct	_jc_javax_swing_plaf_basic_BasicLookAndFeel$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$vmethods	_jc_javax_swing_plaf_basic_BasicLookAndFeel$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$vtable	_jc_javax_swing_plaf_basic_BasicLookAndFeel$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$vtype	_jc_javax_swing_plaf_basic_BasicLookAndFeel$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_basic_BasicLookAndFeel$fields_struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicLookAndFeel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_UIDefaults$object *_jc_javax_swing_plaf_basic_BasicLookAndFeel$method$getDefaults$87ffe4e04898b5f1(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicLookAndFeel$method$initClassDefaults$35477cab17689fae(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicLookAndFeel$method$initComponentDefaults$b280e29c4e58de45(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicLookAndFeel$method$initSystemColorDefaults$4d490ebd205ea2d1(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicLookAndFeel$method$loadResourceBundle$b83922b5072c9519(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicLookAndFeel$method$loadSystemColors$3d217644e7c3cafd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *, struct _jc_object_array *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicLookAndFeel$method_info$getDefaults$87ffe4e04898b5f1;
extern _jc_method _jc_javax_swing_plaf_basic_BasicLookAndFeel$method_info$initClassDefaults$35477cab17689fae;
extern _jc_method _jc_javax_swing_plaf_basic_BasicLookAndFeel$method_info$initComponentDefaults$b280e29c4e58de45;
extern _jc_method _jc_javax_swing_plaf_basic_BasicLookAndFeel$method_info$initSystemColorDefaults$4d490ebd205ea2d1;
extern _jc_method _jc_javax_swing_plaf_basic_BasicLookAndFeel$method_info$loadResourceBundle$b83922b5072c9519;
extern _jc_method _jc_javax_swing_plaf_basic_BasicLookAndFeel$method_info$loadSystemColors$3d217644e7c3cafd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$vmethods {
	struct _jc_javax_swing_UIDefaults$object	*(*getDefaults$87ffe4e04898b5f1)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *) _JC_JCNI_ATTR;
	void	(*initClassDefaults$35477cab17689fae)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;
	void	(*initComponentDefaults$b280e29c4e58de45)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;
	void	(*initSystemColorDefaults$4d490ebd205ea2d1)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;
	void	(*loadResourceBundle$b83922b5072c9519)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;
	void	(*loadSystemColors$3d217644e7c3cafd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object *, struct _jc_javax_swing_UIDefaults$object *, struct _jc_object_array *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_LookAndFeel$vmethods	javax_swing_LookAndFeel;
	_jc_javax_swing_plaf_basic_BasicLookAndFeel$vmethods	javax_swing_plaf_basic_BasicLookAndFeel;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicLookAndFeel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$refs {
    _jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_refs	javax_swing_plaf_basic_BasicLookAndFeel;
    _jc_javax_swing_LookAndFeel$sub_refs	javax_swing_LookAndFeel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_LookAndFeel$sub_nonrefs	javax_swing_LookAndFeel;
    _jc_javax_swing_plaf_basic_BasicLookAndFeel$sub_nonrefs	javax_swing_plaf_basic_BasicLookAndFeel;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicLookAndFeel$object {
	_jc_javax_swing_plaf_basic_BasicLookAndFeel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicLookAndFeel$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicLookAndFeel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicLookAndFeel$vtype _jc_javax_swing_plaf_basic_BasicLookAndFeel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicLookAndFeel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicLookAndFeel$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicLookAndFeel_H_ */
